"""
 * py-smtper OSS
 * author: github.com/alisharify7
 * email: alisharifyofficial@gmail.com
 * license: see LICENSE for more details.
 * Copyright (c) 2024 - ali sharifi
 * https://github.com/alisharify7/py-smtper
"""

from .klass import MailManager
from .utils import create_mail_manager